@@ -25,10 +25,15 @@ class FuzzyMap(dict):
             # Calculate matching coefficient of each key via fuzz.ratio
             coefficients = {k: fuzz.ratio(k, key) for k in self.keys()}
             matching = max(coefficients, key=lambda k: coefficients[k])
-            if coefficients[matching] > self.ratio:
+            if coefficients[matching] >= self.ratio:
                 return matching
         return key
 
+    def get(self, key, default=None):
+        """Invokes the __getitem__ to keep the `FuzzyMap` behavior"""
+
+        return self[key] or default
+
     def __missing__(self, key):
         return super().get(self.closest_key(key))
 
